@@ -10,24 +10,19 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from __future__ import division
 import logging
 import sys
 import threading
 import time
-from collections import namedtuple
-from collections import defaultdict
+from collections import defaultdict, namedtuple
 
-from s3transfer.exceptions import CancelledError
-from s3transfer.exceptions import FatalError
+from s3transfer.exceptions import CancelledError, FatalError
 from s3transfer.subscribers import BaseSubscriber
 
-from awscli.compat import queue, ensure_text_type
-from awscli.customizations.s3.utils import human_readable_size
-from awscli.customizations.utils import uni_print
-from awscli.customizations.s3.utils import WarningResult
+from awscli.compat import ensure_text_type, queue
 from awscli.customizations.s3.subscribers import OnDoneFilteredSubscriber
-
+from awscli.customizations.s3.utils import WarningResult, human_readable_size
+from awscli.customizations.utils import uni_print
 
 LOGGER = logging.getLogger(__name__)
 
@@ -51,8 +46,8 @@ def _create_new_result_cls(name, extra_fields=None, base_cls=BaseResult):
 QueuedResult = _create_new_result_cls('QueuedResult', ['total_transfer_size'])
 
 ProgressResult = _create_new_result_cls(
-    'ProgressResult', ['bytes_transferred', 'total_transfer_size',
-                       'timestamp'])
+    'ProgressResult', ['bytes_transferred', 'total_transfer_size', 'timestamp']
+)
 
 SuccessResult = _create_new_result_cls('SuccessResult')
 
@@ -65,13 +60,15 @@ ErrorResult = namedtuple('ErrorResult', ['exception'])
 CtrlCResult = _create_new_result_cls('CtrlCResult', base_cls=ErrorResult)
 
 CommandResult = namedtuple(
-    'CommandResult', ['num_tasks_failed', 'num_tasks_warned'])
+    'CommandResult', ['num_tasks_failed', 'num_tasks_warned']
+)
 
 FinalTotalSubmissionsResult = namedtuple(
-    'FinalTotalSubmissionsResult', ['total_submissions'])
+    'FinalTotalSubmissionsResult', ['total_submissions']
+)
 
 
-class ShutdownThreadRequest(object):
+class ShutdownThreadRequest:
     pass
 
 
@@ -91,7 +88,7 @@ class QueuedResultSubscriber(BaseResultSubscriber):
                 transfer_type=self._transfer_type,
                 src=self._src,
                 dest=self._dest,
-                total_transfer_size=self._size
+                total_transfer_size=self._size,
             )
         )
 
@@ -105,7 +102,7 @@ class ProgressResultSubscriber(BaseResultSubscriber):
                 dest=self._dest,
                 bytes_transferred=bytes_transferred,
                 timestamp=time.time(),
-                total_transfer_size=self._size
+                total_transfer_size=self._size,
             )
         )
 
@@ -137,14 +134,16 @@ class DoneResultSubscriber(BaseResultSubscriber, OnDoneFilteredSubscriber):
             )
 
 
-class BaseResultHandler(object):
+class BaseResultHandler:
     """Base handler class to be called in the ResultProcessor"""
+
     def __call__(self, result):
         raise NotImplementedError('__call__()')
 
 
 class ResultRecorder(BaseResultHandler):
     """Records and track transfer statistics based on results received"""
+
     def __init__(self):
         self.bytes_transferred = 0
         self.bytes_failed_to_transfer = 0
@@ -175,14 +174,15 @@ class ResultRecorder(BaseResultHandler):
 
     def expected_totals_are_final(self):
         return (
-            self.final_expected_files_transferred ==
-            self.expected_files_transferred
+            self.final_expected_files_transferred
+            == self.expected_files_transferred
         )
 
     def __call__(self, result):
         """Record the result of an individual Result object"""
         self._result_handler_map.get(type(result), self._record_noop)(
-            result=result)
+            result=result
+        )
 
     def _get_ongoing_dict_key(self, result):
         if not isinstance(result, BaseResult):
@@ -194,7 +194,7 @@ class ResultRecorder(BaseResultHandler):
         for result_property in [result.transfer_type, result.src, result.dest]:
             if result_property is not None:
                 key_parts.append(ensure_text_type(result_property))
-        return u':'.join(key_parts)
+        return ':'.join(key_parts)
 
     def _pop_result_from_ongoing_dicts(self, result):
         ongoing_key = self._get_ongoing_dict_key(result)
@@ -210,8 +210,9 @@ class ResultRecorder(BaseResultHandler):
         if self.start_time is None:
             self.start_time = time.time()
         total_transfer_size = result.total_transfer_size
-        self._ongoing_total_sizes[
-            self._get_ongoing_dict_key(result)] = total_transfer_size
+        self._ongoing_total_sizes[self._get_ongoing_dict_key(result)] = (
+            total_transfer_size
+        )
         # The total transfer size can be None if we do not know the size
         # immediately so do not add to the total right away.
         if total_transfer_size:
@@ -221,8 +222,9 @@ class ResultRecorder(BaseResultHandler):
     def _record_progress_result(self, result, **kwargs):
         bytes_transferred = result.bytes_transferred
         self._update_ongoing_transfer_size_if_unknown(result)
-        self._ongoing_progress[
-            self._get_ongoing_dict_key(result)] += bytes_transferred
+        self._ongoing_progress[self._get_ongoing_dict_key(result)] += (
+            bytes_transferred
+        )
         self.bytes_transferred += bytes_transferred
         # Since the start time is captured in the result recorder and
         # capture timestamps in the subscriber, there is a chance that if
@@ -233,7 +235,8 @@ class ResultRecorder(BaseResultHandler):
         # negative progress being displayed or zero division occurring.
         if result.timestamp > self.start_time:
             self.bytes_transfer_speed = self.bytes_transferred / (
-                result.timestamp - self.start_time)
+                result.timestamp - self.start_time
+            )
 
     def _update_ongoing_transfer_size_if_unknown(self, result):
         # This is a special case when the transfer size was previous not
@@ -270,7 +273,8 @@ class ResultRecorder(BaseResultHandler):
         # the count for bytes transferred by just adding on the remaining bytes
         # that did not get transferred.
         total_progress, total_file_size = self._pop_result_from_ongoing_dicts(
-            result)
+            result
+        )
         if total_file_size is not None:
             progress_left = total_file_size - total_progress
             self.bytes_failed_to_transfer += progress_left
@@ -299,25 +303,17 @@ class ResultPrinter(BaseResultHandler):
     FILE_PROGRESS_FORMAT = (
         'Completed {files_completed} file(s) with ' + _FILES_REMAINING
     )
-    SUCCESS_FORMAT = (
-        u'{transfer_type}: {transfer_location}'
-    )
-    DRY_RUN_FORMAT = u'(dryrun) ' + SUCCESS_FORMAT
-    FAILURE_FORMAT = (
-        u'{transfer_type} failed: {transfer_location} {exception}'
-    )
+    SUCCESS_FORMAT = '{transfer_type}: {transfer_location}'
+    DRY_RUN_FORMAT = '(dryrun) ' + SUCCESS_FORMAT
+    FAILURE_FORMAT = '{transfer_type} failed: {transfer_location} {exception}'
     # TODO: Add "warning: " prefix once all commands are converted to using
     # result printer and remove "warning: " prefix from ``create_warning``.
-    WARNING_FORMAT = (
-        u'{message}'
-    )
-    ERROR_FORMAT = (
-        u'fatal error: {exception}'
-    )
+    WARNING_FORMAT = '{message}'
+    ERROR_FORMAT = 'fatal error: {exception}'
     CTRL_C_MSG = 'cancelled: ctrl-c received'
 
-    SRC_DEST_TRANSFER_LOCATION_FORMAT = u'{src} to {dest}'
-    SRC_TRANSFER_LOCATION_FORMAT = u'{src}'
+    SRC_DEST_TRANSFER_LOCATION_FORMAT = '{src} to {dest}'
+    SRC_TRANSFER_LOCATION_FORMAT = '{src}'
 
     def __init__(self, result_recorder, out_file=None, error_file=None):
         """Prints status of ongoing transfer
@@ -349,14 +345,14 @@ class ResultPrinter(BaseResultHandler):
             ErrorResult: self._print_error,
             CtrlCResult: self._print_ctrl_c,
             DryRunResult: self._print_dry_run,
-            FinalTotalSubmissionsResult:
-                self._clear_progress_if_no_more_expected_transfers,
+            FinalTotalSubmissionsResult: self._clear_progress_if_no_more_expected_transfers,
         }
 
     def __call__(self, result):
         """Print the progress of the ongoing transfer based on a result"""
         self._result_handler_map.get(type(result), self._print_noop)(
-            result=result)
+            result=result
+        )
 
     def _print_noop(self, **kwargs):
         # If the result does not have a handler, then do nothing with it.
@@ -365,7 +361,7 @@ class ResultPrinter(BaseResultHandler):
     def _print_dry_run(self, result, **kwargs):
         statement = self.DRY_RUN_FORMAT.format(
             transfer_type=result.transfer_type,
-            transfer_location=self._get_transfer_location(result)
+            transfer_location=self._get_transfer_location(result),
         )
         statement = self._adjust_statement_padding(statement)
         self._print_to_out_file(statement)
@@ -373,7 +369,7 @@ class ResultPrinter(BaseResultHandler):
     def _print_success(self, result, **kwargs):
         success_statement = self.SUCCESS_FORMAT.format(
             transfer_type=result.transfer_type,
-            transfer_location=self._get_transfer_location(result)
+            transfer_location=self._get_transfer_location(result),
         )
         success_statement = self._adjust_statement_padding(success_statement)
         self._print_to_out_file(success_statement)
@@ -383,7 +379,7 @@ class ResultPrinter(BaseResultHandler):
         failure_statement = self.FAILURE_FORMAT.format(
             transfer_type=result.transfer_type,
             transfer_location=self._get_transfer_location(result),
-            exception=result.exception
+            exception=result.exception,
         )
         failure_statement = self._adjust_statement_padding(failure_statement)
         self._print_to_error_file(failure_statement)
@@ -397,7 +393,8 @@ class ResultPrinter(BaseResultHandler):
 
     def _print_error(self, result, **kwargs):
         self._flush_error_statement(
-            self.ERROR_FORMAT.format(exception=result.exception))
+            self.ERROR_FORMAT.format(exception=result.exception)
+        )
 
     def _print_ctrl_c(self, result, **kwargs):
         self._flush_error_statement(self.CTRL_C_MSG)
@@ -410,7 +407,8 @@ class ResultPrinter(BaseResultHandler):
         if result.dest is None:
             return self.SRC_TRANSFER_LOCATION_FORMAT.format(src=result.src)
         return self.SRC_DEST_TRANSFER_LOCATION_FORMAT.format(
-            src=result.src, dest=result.dest)
+            src=result.src, dest=result.dest
+        )
 
     def _redisplay_progress(self):
         # Reset to zero because done statements are printed with new lines
@@ -426,34 +424,40 @@ class ResultPrinter(BaseResultHandler):
     def _print_progress(self, **kwargs):
         # Get all of the statistics in the correct form.
         remaining_files = self._get_expected_total(
-            str(self._result_recorder.expected_files_transferred -
-                self._result_recorder.files_transferred)
+            str(
+                self._result_recorder.expected_files_transferred
+                - self._result_recorder.files_transferred
+            )
         )
 
         # Create the display statement.
         if self._result_recorder.expected_bytes_transferred > 0:
             bytes_completed = human_readable_size(
-                self._result_recorder.bytes_transferred +
-                self._result_recorder.bytes_failed_to_transfer
+                self._result_recorder.bytes_transferred
+                + self._result_recorder.bytes_failed_to_transfer
             )
             expected_bytes_completed = self._get_expected_total(
                 human_readable_size(
-                    self._result_recorder.expected_bytes_transferred))
+                    self._result_recorder.expected_bytes_transferred
+                )
+            )
 
-            transfer_speed = human_readable_size(
-                self._result_recorder.bytes_transfer_speed) + '/s'
+            transfer_speed = (
+                human_readable_size(self._result_recorder.bytes_transfer_speed)
+                + '/s'
+            )
             progress_statement = self.BYTE_PROGRESS_FORMAT.format(
                 bytes_completed=bytes_completed,
                 expected_bytes_completed=expected_bytes_completed,
                 transfer_speed=transfer_speed,
-                remaining_files=remaining_files
+                remaining_files=remaining_files,
             )
         else:
             # We're not expecting any bytes to be transferred, so we should
             # only print of information about number of files transferred.
             progress_statement = self.FILE_PROGRESS_FORMAT.format(
                 files_completed=self._result_recorder.files_transferred,
-                remaining_files=remaining_files
+                remaining_files=remaining_files,
             )
 
         if not self._result_recorder.expected_totals_are_final():
@@ -461,7 +465,8 @@ class ResultPrinter(BaseResultHandler):
 
         # Make sure that it overrides any previous progress bar.
         progress_statement = self._adjust_statement_padding(
-                progress_statement, ending_char='\r')
+            progress_statement, ending_char='\r'
+        )
         # We do not want to include the carriage return in this calculation
         # as progress length is used for determining whitespace padding.
         # So we subtract one off of the length.
@@ -473,7 +478,8 @@ class ResultPrinter(BaseResultHandler):
     def _get_expected_total(self, expected_total):
         if not self._result_recorder.expected_totals_are_final():
             return self._ESTIMATED_EXPECTED_TOTAL.format(
-                expected_total=expected_total)
+                expected_total=expected_total
+            )
         return expected_total
 
     def _adjust_statement_padding(self, print_statement, ending_char='\n'):
@@ -500,12 +506,14 @@ class ResultPrinter(BaseResultHandler):
 
 class NoProgressResultPrinter(ResultPrinter):
     """A result printer that doesn't print progress"""
+
     def _print_progress(self, **kwargs):
         pass
 
 
 class OnlyShowErrorsResultPrinter(ResultPrinter):
     """A result printer that only prints out errors"""
+
     def _print_progress(self, **kwargs):
         pass
 
@@ -537,7 +545,8 @@ class ResultProcessor(threading.Thread):
                 if isinstance(result, ShutdownThreadRequest):
                     LOGGER.debug(
                         'Shutdown request received in result processing '
-                        'thread, shutting down result thread.')
+                        'thread, shutting down result thread.'
+                    )
                     break
                 if self._result_handlers_enabled:
                     self._process_result(result)
@@ -558,10 +567,14 @@ class ResultProcessor(threading.Thread):
             except Exception as e:
                 LOGGER.debug(
                     'Error processing result %s with handler %s: %s',
-                    result, result_handler, e, exc_info=True)
+                    result,
+                    result_handler,
+                    e,
+                    exc_info=True,
+                )
 
 
-class CommandResultRecorder(object):
+class CommandResultRecorder:
     def __init__(self, result_queue, result_recorder, result_processor):
         """Records the result for an entire command
 
@@ -600,7 +613,7 @@ class CommandResultRecorder(object):
         """
         return CommandResult(
             self._result_recorder.files_failed + self._result_recorder.errors,
-            self._result_recorder.files_warned
+            self._result_recorder.files_warned,
         )
 
     def notify_total_submissions(self, total):
@@ -612,8 +625,11 @@ class CommandResultRecorder(object):
 
     def __exit__(self, exc_type, exc_value, *args):
         if exc_type:
-            LOGGER.debug('Exception caught during command execution: %s',
-                         exc_value, exc_info=True)
+            LOGGER.debug(
+                'Exception caught during command execution: %s',
+                exc_value,
+                exc_info=True,
+            )
             self.result_queue.put(ErrorResult(exception=exc_value))
             self.shutdown()
             return True
